==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/AssigningScatterStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningScatterStyleEventArgsDescription } from "./AssigningScatterStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningScatterStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningScatterStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningScatterStyleEventArgsDescriptionMetadata.a == null) {
                AssigningScatterStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningScatterStyleEventArgsDescriptionMetadata.c(AssigningScatterStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningScatterStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(AssigningScatterStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningScatterStyleEventArgsDescriptionMetadata.b(a);
            a.ad("AssigningScatterStyleEventArgs", () => new AssigningScatterStyleEventArgsDescription());
            a.ac("AssigningScatterStyleEventArgs", AssigningScatterStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningScatterStyleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningScatterStyleEventArgsDescriptionMetadata, 'AssigningScatterStyleEventArgsDescriptionMetadata');
    AssigningScatterStyleEventArgsDescriptionMetadata.a = null;
    return AssigningScatterStyleEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/AssigningScatterStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningScatterStyleEventArgsDescription } from "./AssigningScatterStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningScatterStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningScatterStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningScatterStyleEventArgsDescriptionMetadata.a == null) {
                AssigningScatterStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningScatterStyleEventArgsDescriptionMetadata.c(AssigningScatterStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningScatterStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningScatterStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningScatterStyleEventArgsDescriptionMetadata.b(a);
            a.ae("AssigningScatterStyleEventArgs", () => new AssigningScatterStyleEventArgsDescription());
            a.ad("AssigningScatterStyleEventArgs", AssigningScatterStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningScatterStyleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningScatterStyleEventArgsDescriptionMetadata, 'AssigningScatterStyleEventArgsDescriptionMetadata');
    AssigningScatterStyleEventArgsDescriptionMetadata.a = null;
    return AssigningScatterStyleEventArgsDescriptionMetadata;
})();
